import { DataTypes, Model, Optional, Sequelize } from "sequelize";

interface CheckInAttributes {
  id: string;
  startTime: Date;
  estimatedEndTime: Date;
  email: string;
  fullNameOfResponsableClient: string;
  additionalClients: Array<string>;
  boatId: string;
}
export interface CheckInAttributesInput
  extends Optional<CheckInAttributes, "id"> {}

class CheckIn
  extends Model<CheckInAttributes, CheckInAttributesInput>
  implements CheckInAttributes
{
  declare id: string;
  declare startTime: Date;
  declare estimatedEndTime: Date;
  declare email: string;
  declare fullNameOfResponsableClient: string;
  declare additionalClients: Array<string>;
  declare boatId: string;

  declare readonly createdAt: Date;
  declare readonly updatedAt: Date;
}

export const initCheckIn = async (sequelizeConnection: Sequelize) => {
  CheckIn.init(
    {
      id: {
        type: DataTypes.UUID,
        defaultValue: DataTypes.UUIDV4,
        primaryKey: true,
        allowNull: false,
      },
      startTime: {
        type: DataTypes.DATE,
        allowNull: false,
      },
      estimatedEndTime: {
        type: DataTypes.DATE,
        allowNull: false,
      },
      email: {
        type: new DataTypes.STRING(),
        allowNull: false,
      },
      fullNameOfResponsableClient: {
        type: new DataTypes.STRING(),
        allowNull: false,
      },
      additionalClients: {
        type: new DataTypes.ARRAY(DataTypes.STRING),
      },
      boatId: {
        type: DataTypes.UUID,
        references: {
          model: "boat",
          key: "id",
        },
      },
    },
    {
      tableName: "checkin",
      sequelize: sequelizeConnection,
    }
  );
};

export default CheckIn;
